import { ref } from 'vue-demi';
import { tryOnUnmounted, isDef } from '@vueuse/shared';

function getData(docRef) {
    const data = docRef.data();
    if (data) {
        Object.defineProperty(data, 'id', {
            value: docRef.id.toString(),
            writable: false,
        });
    }
    return data;
}
function isDocumentReference(docRef) {
    return Boolean(docRef.parent);
}
function useFirestore(docRef, errorHandler = (err) => console.error(err)) {
    if (isDocumentReference(docRef)) {
        const data = ref(null);
        const close = docRef.onSnapshot((snapshot) => {
            // @ts-ignore
            data.value = getData(snapshot) || null;
        }, errorHandler);
        tryOnUnmounted(() => {
            close();
        });
        return data;
    }
    else {
        const data = ref([]);
        const close = docRef.onSnapshot((snapshot) => {
            data.value = snapshot.docs.map(getData).filter(isDef);
        }, errorHandler);
        tryOnUnmounted(() => {
            close();
        });
        return data;
    }
}

function useRTDB(docRef) {
    const data = ref(null);
    function update(snapshot) {
        data.value = snapshot.val();
    }
    docRef.on('value', update);
    tryOnUnmounted(() => {
        docRef.off('value', update);
    });
    return data;
}

export { useFirestore, useRTDB };
