(function (global, factory) {
  typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-demi'), require('@vueuse/shared')) :
  typeof define === 'function' && define.amd ? define(['exports', 'vue-demi', '@vueuse/shared'], factory) :
  (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.VueUseFirebase = {}, global.VueDemi, global.VueUseShared));
}(this, (function (exports, vueDemi, shared) { 'use strict';

  function getData(docRef) {
      const data = docRef.data();
      if (data) {
          Object.defineProperty(data, 'id', {
              value: docRef.id.toString(),
              writable: false,
          });
      }
      return data;
  }
  function isDocumentReference(docRef) {
      return Boolean(docRef.parent);
  }
  function useFirestore(docRef, errorHandler = (err) => console.error(err)) {
      if (isDocumentReference(docRef)) {
          const data = vueDemi.ref(null);
          const close = docRef.onSnapshot((snapshot) => {
              // @ts-ignore
              data.value = getData(snapshot) || null;
          }, errorHandler);
          shared.tryOnUnmounted(() => {
              close();
          });
          return data;
      }
      else {
          const data = vueDemi.ref([]);
          const close = docRef.onSnapshot((snapshot) => {
              data.value = snapshot.docs.map(getData).filter(shared.isDef);
          }, errorHandler);
          shared.tryOnUnmounted(() => {
              close();
          });
          return data;
      }
  }

  function useRTDB(docRef) {
      const data = vueDemi.ref(null);
      function update(snapshot) {
          data.value = snapshot.val();
      }
      docRef.on('value', update);
      shared.tryOnUnmounted(() => {
          docRef.off('value', update);
      });
      return data;
  }

  exports.useFirestore = useFirestore;
  exports.useRTDB = useRTDB;

  Object.defineProperty(exports, '__esModule', { value: true });

})));
